@media (max-width: 767px) {
    .nav-xs {
        margin: 0;
    }
}

.txt-args {
    font-size: 10px;
    display: block;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 100px;
}