{% extends "base.html" %}
{% block content_header %}
<h1>Server Stats</h1>
{% endblock %}
{% block content_body %}
<div class="box">
    <div class="box-header">
        <h3 class="box-title">Server Stats</h3>
    </div>
    <div class="box-body">
    </div>
    <div class="box-footer text-black">
        <div class="row">
            {% for server in servers %}
            <div class="col-sm-12">
                <!-- Progress bars -->
                <div class="clearfix">
                    <span class="pull-left">{{ server }}</span>
                </div>
                <div class="progress">
                    <div class="progress-bar progress-bar-green" style="width: 100%;"></div>
                </div>
            </div>
            {% endfor %}
        </div>
    </div>
</div>
{% endblock %}